% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{deviance.tweedie.numeric}
\alias{deviance.tweedie.numeric}
\title{Tweedie Deviance}
\usage{
\method{deviance}{tweedie.numeric}(actual, predicted, power = 2, ...)
}
\arguments{
\item{actual, predicted}{A pair of <\link{double}> vectors of \link{length} \eqn{n}.}

\item{power}{A <\link{double}> value, default = 2.
Tweedie power parameter. Either power <= 0 or power >= 1.

The higher \eqn{power}, the less weight is given to extreme deviations between actual and predicted values.
\itemize{
\item \strong{power < 0:} Extreme stable distribution. Requires: predicted > 0.
\item \strong{power = 0:} Normal distribution, output corresponds to \code{\link[=mse]{mse()}}, actual and predicted can be any real numbers.
\item \strong{power = 1:} Poisson distribution (\code{\link[=deviance.poisson]{deviance.poisson()}}). Requires: actual >= 0 and predicted > 0.
\item \strong{1 < power < 2:} Compound Poisson distribution. Requires: actual >= 0 and predicted > 0.
\item \strong{power = 2:} Gamma distribution (\code{\link[=deviance.gamma]{deviance.gamma()}}). Requires: actual > 0 and predicted > 0.
\item \strong{power = 3:} Inverse Gaussian distribution. Requires: actual > 0 and predicted > 0.
\item \strong{otherwise:} Positive stable distribution. Requires: actual > 0 and predicted > 0.
}}

\item{...}{Arguments passed into other methods}
}
\value{
A <\link{double}> value
}
\description{
A generic S3 function to compute the \emph{tweedie deviance} score for a regression model. This function dispatches to S3 methods in \code{\link[=deviance.tweedie]{deviance.tweedie()}} and performs no input validation. If you supply \link{NA} values or vectors of unequal \link{length} (e.g. \code{length(x) != length(y)}), the underlying \code{C++} code may trigger undefined behavior and crash your \code{R} session.
\subsection{Defensive measures}{

Because \code{\link[=deviance.tweedie]{deviance.tweedie()}} operates on raw pointers, pointer-level faults (e.g. from \link{NA} or mismatched \link{length}) occur before any \code{R}-level error handling.  Wrapping calls in \code{\link[=try]{try()}} or \code{\link[=tryCatch]{tryCatch()}} will \emph{not} prevent \code{R}-session crashes.

To guard against this, wrap \code{\link[=deviance.tweedie]{deviance.tweedie()}} in a "safe" validator that checks for \link{NA} values and matching \link{length}, for example:

\if{html}{\out{<div class="sourceCode r">}}\preformatted{safe_deviance.tweedie <- function(x, y, ...) \{
  stopifnot(
    !anyNA(x), !anyNA(y),
    length(x) == length(y)
  )
  deviance.tweedie(x, y, ...)
\}
}\if{html}{\out{</div>}}

Apply the same pattern to any custom metric functions to ensure input sanity before calling the underlying \code{C++} code.
}
}
\examples{
## Generate actual
## and predicted values
actual_values    <- c(1.3, 0.4, 1.2, 1.4, 1.9, 1.0, 1.2)
predicted_values <- c(0.7, 0.5, 1.1, 1.2, 1.8, 1.1, 0.2)

## Evaluate performance
SLmetrics::deviance.tweedie(
   actual    = actual_values, 
   predicted = predicted_values
)

}
\references{
James, Gareth, et al. An introduction to statistical learning. Vol. 112. No. 1. New York: springer, 2013.

Hastie, Trevor. "The elements of statistical learning: data mining, inference, and prediction." (2009).

Virtanen, Pauli, et al. "SciPy 1.0: fundamental algorithms for scientific computing in Python." Nature methods 17.3 (2020): 261-272.

Pedregosa, Fabian, et al. "Scikit-learn: Machine learning in Python." the Journal of machine Learning research 12 (2011): 2825-2830.
}
\seealso{
Other Regression: 
\code{\link{ccc}()},
\code{\link{deviance.gamma}()},
\code{\link{deviance.poisson}()},
\code{\link{gmse}()},
\code{\link{huberloss}()},
\code{\link{maape}()},
\code{\link{mae}()},
\code{\link{mape}()},
\code{\link{mpe}()},
\code{\link{mse}()},
\code{\link{pinball}()},
\code{\link{rae}()},
\code{\link{rmse}()},
\code{\link{rmsle}()},
\code{\link{rrmse}()},
\code{\link{rrse}()},
\code{\link{rsq}()},
\code{\link{smape}()}

Other Supervised Learning: 
\code{\link{accuracy}()},
\code{\link{auc.pr.curve}()},
\code{\link{auc.roc.curve}()},
\code{\link{baccuracy}()},
\code{\link{brier.score}()},
\code{\link{ccc}()},
\code{\link{ckappa}()},
\code{\link{cmatrix}()},
\code{\link{cross.entropy}()},
\code{\link{deviance.gamma}()},
\code{\link{deviance.poisson}()},
\code{\link{dor}()},
\code{\link{fbeta}()},
\code{\link{fdr}()},
\code{\link{fer}()},
\code{\link{fmi}()},
\code{\link{fpr}()},
\code{\link{gmse}()},
\code{\link{hammingloss}()},
\code{\link{huberloss}()},
\code{\link{jaccard}()},
\code{\link{logloss}()},
\code{\link{maape}()},
\code{\link{mae}()},
\code{\link{mape}()},
\code{\link{mcc}()},
\code{\link{mpe}()},
\code{\link{mse}()},
\code{\link{nlr}()},
\code{\link{npv}()},
\code{\link{pinball}()},
\code{\link{plr}()},
\code{\link{pr.curve}()},
\code{\link{precision}()},
\code{\link{rae}()},
\code{\link{recall}()},
\code{\link{relative.entropy}()},
\code{\link{rmse}()},
\code{\link{rmsle}()},
\code{\link{roc.curve}()},
\code{\link{rrmse}()},
\code{\link{rrse}()},
\code{\link{rsq}()},
\code{\link{shannon.entropy}()},
\code{\link{smape}()},
\code{\link{specificity}()},
\code{\link{zerooneloss}()}
}
\concept{Machine learning performance evaluation}
\keyword{evaluation}
\keyword{regression}
